summaryrefslogtreecommitdiffstats
path: root/compatibility-server/src
diff options
context:
space:
mode:
authorDenis Anisimov <denis@vaadin.com>2016-10-20 11:12:58 +0300
committerVaadin Code Review <review@vaadin.com>2016-10-25 06:46:17 +0000
commit862270140d287aba33dce03dc963db4421ebeb1a (patch)
tree2da2634f4dbec1814c1d6d7e01f44d6e12a36c91 /compatibility-server/src
parent0decd87411d98cf0d03db35fb6e5d70637ff864c (diff)
downloadvaadin-framework-862270140d287aba33dce03dc963db4421ebeb1a.tar.gz
vaadin-framework-862270140d287aba33dce03dc963db4421ebeb1a.zip
Update ValueChange API to use Component and HasValue<>.
Change-Id: I785aa82d925cadee42cc1b17d345a8923f6dc8cc
Diffstat (limited to 'compatibility-server/src')
-rw-r--r--compatibility-server/src/main/java/com/vaadin/v7/ui/Field.java4
1 files changed, 2 insertions, 2 deletions
diff --git a/compatibility-server/src/main/java/com/vaadin/v7/ui/Field.java b/compatibility-server/src/main/java/com/vaadin/v7/ui/Field.java
index 79c685c71b..d98153da29 100644
--- a/compatibility-server/src/main/java/com/vaadin/v7/ui/Field.java
+++ b/compatibility-server/src/main/java/com/vaadin/v7/ui/Field.java
@@ -17,7 +17,7 @@
package com.vaadin.v7.ui;
import com.vaadin.data.HasRequired;
-import com.vaadin.data.HasValue.ValueChange;
+import com.vaadin.data.HasValue.ValueChangeEvent;
import com.vaadin.ui.Component;
import com.vaadin.ui.Component.Focusable;
import com.vaadin.v7.data.BufferedValidatable;
@@ -96,7 +96,7 @@ public interface Field<T> extends Component, BufferedValidatable, Property<T>,
* @author Vaadin Ltd.
* @since 3.0
*
* @deprecated As of 8.0, replaced by {@link ValueChange}.
*/
@Deprecated
@SuppressWarnings("serial")
@@ -96,7 +96,7 @@ public interface Field<T> extends Component, BufferedValidatable, Property<T>,
* @since 3.0
*
- * @deprecated As of 8.0, replaced by {@link ValueChange}.
+ * @deprecated As of 8.0, replaced by {@link ValueChangeEvent}.
*/